@@ -3,6 +3,7 @@ from typing import Iterable
 
 from django.db.models import Model, QuerySet
 from django.db.models.query import RawQuerySet
+from django.http import StreamingHttpResponse
 from django.template.response import TemplateResponse
 from djangorestframework_camel_case.parser import (
     CamelCaseFormParser,
@@ -128,6 +129,7 @@ class APIRouter:
         methods=("post",),
         renderers=(CamelCaseJSONRenderer,),
         template=None,
+        stream=False,
         parsers=(CamelCaseJSONParser, CamelCaseFormParser, CamelCaseMultiPartParser),
         tags=None,
     ):
@@ -201,6 +203,13 @@ class APIRouter:
 
                 if template:
                     return TemplateResponse(request, template, response_data)
+
+                if stream:
+                    StreamingHttpResponse(
+                        response_data,
+                        status=200,
+                        content_type="application/json",
+                    )
                 return Response(response_data)
 
             if path:
